Constant

Struct Constant 

pub struct Constant {
    pub name: Option<String>,
    pub ty: Type,
    pub value: ConstantValue,
    pub spec_id: Option<u32>,
}
Constant or specialization constant record.

Fields

name: Option<String>ty: Type

Type of constant.

value: ConstantValue

Defined value of constant, or default value of specialization constant.

spec_id: Option<u32>

Specialization constant ID, notice that this is NOT an instruction ID. It is used to identify specialization constants for graphics libraries.

Implementations

Source

impl Constant

pub fn new(name: Option<String>, ty: Type, value: ConstantValue) -> Constant

Create a constant record with name, type and value. ty must be a ScalarType.

pub fn new_itm(ty: Type, value: ConstantValue) -> Constant

Create an intermediate constant record with type and value. Intermediate constants don’t have names because they contribute to subexpressions in arithmetic.

pub fn new_spec( name: Option<String>, ty: Type, value: ConstantValue, spec_id: u32, ) -> Constant

Create a specialization constant record with name, type, default value and a SpecId.